@@ -166,6 +166,25 @@ async function handleSurveyResponseActions(
   );
 }
 
+// Special case for answers that depend on creating a new record in the database
+// and store the ID of the new record in the answer body. Currently only used for photos.
+async function getBodyForAnswer(dataElementType: string, value: any, models: Models) {
+  if (dataElementType === PROGRAM_DATA_ELEMENT_TYPES.PHOTO && !!value) {
+    const { size, data } = value as unknown as { size: number; data: string };
+    const { id: attachmentId } = await models.Attachment.create(
+      models.Attachment.sanitizeForDatabase({
+        type: 'image/jpeg',
+        size,
+        data,
+      }),
+    );
+    // Store the attachment ID in the answer body
+    return attachmentId;
+  }
+
+  return getStringValue(dataElementType, value);
+}
+
 export class SurveyResponse extends Model {
   declare id: string;
   declare startTime?: string;
@@ -232,7 +251,7 @@ export class SurveyResponse extends Model {
     );
   }
 
-  static buildSyncLookupQueryDetails() {
+  static async buildSyncLookupQueryDetails() {
     return buildEncounterLinkedLookupFilter(this);
   }
 
@@ -382,7 +401,7 @@ export class SurveyResponse extends Model {
       if (!dataElement) {
         throw new Error(`no data element for question: ${dataElementId}`);
       }
-      const body = getStringValue(dataElement.type, value);
+      const body = await getBodyForAnswer(dataElement.type, value, models);
       // Don't create null answers
       if (body === null) {
         continue;
